SQLProvider

QueryInspection Module

Query debugging and inspection utilities

Nested modules

Modules Description

IQueryableExtensions

Extension methods for IQueryable to provide EF Core-like query inspection capabilities

Functions and values

Function or value Description

toQueryString query

Full Usage: toQueryString query

Parameters:
Returns: string * (string * obj) array

Generates the SQL query string and parameters without executing the query. Note: This function creates a database connection to access schema metadata for SQL generation, but does not execute any queries against the database. This is useful for debugging, logging, or when you need to execute the query through ADO.NET directly. Returns a tuple of (SQL query string, array of parameter name-value pairs).

query : IQueryable<'T>
Returns: string * (string * obj) array

Type something to start searching.