SQLProvider

IQueryableExtensions Module

Extension methods for IQueryable to provide EF Core-like query inspection capabilities

Type extensions

Type extension Description

this.ToQueryString

Full Usage: this.ToQueryString

Parameters:
    () : unit

Returns: string * (string * obj) array

Generates the SQL query string and parameters without executing the query. Note: This method creates a database connection to access schema metadata for SQL generation, but does not execute any queries against the database. This is useful for debugging, logging, or when you need to execute the query through ADO.NET directly. Returns a tuple of (SQL query string, array of parameter name-value pairs).

Extended Type: IQueryable

() : unit
Returns: string * (string * obj) array

Type something to start searching.