|
|
Allows any level of isolation, including overlapping changes (SQL Server specific)
-
Field type:
IsolationLevel
|
|
|
Special value to indicate that no transaction should be created
-
Field type:
IsolationLevel
|
|
|
Prevents dirty reads but allows non-repeatable reads and phantom reads.
(This describes the default isolation of most DB *engines* - it is NOT SQLProvider's default;
TransactionOptions.Default is Serializable, inherited from System.Transactions.)
-
Field type:
IsolationLevel
|
|
|
Allows dirty reads, non-repeatable reads, and phantom reads (fastest but least safe)
-
Field type:
IsolationLevel
|
|
|
Prevents dirty reads and non-repeatable reads, but phantom reads can occur
-
Field type:
IsolationLevel
|
|
|
Highest isolation level - transactions are completely isolated from each other
-
Field type:
IsolationLevel
|
|
|
SQL Server specific - provides statement-level read consistency using versioning
-
Field type:
IsolationLevel
|
|
|
Use the default isolation level of the database
-
Field type:
IsolationLevel
|