QueryInspection Module
Query debugging and inspection utilities
Nested modules
| Modules | Description |
Functions and values
| Function or value | Description |
Full Usage:
toQueryString query
Parameters:
IQueryable<'T>
Returns: string * (string * obj) array
|
Generates the SQL query string and parameters without executing the query. Note: This function creates a database connection to access schema metadata for SQL generation, but does not execute any queries against the database. This is useful for debugging, logging, or when you need to execute the query through ADO.NET directly. Returns a tuple of (SQL query string, array of parameter name-value pairs).
|